package it.sw.pa.comune.artegna.domain;

import java.util.Random;
import java.util.UUID;
import java.util.concurrent.atomic.AtomicLong;

public class UtenteAppTestSamples {

    private static final Random random = new Random();
    private static final AtomicLong longCount = new AtomicLong(random.nextInt() + (2L * Integer.MAX_VALUE));

    public static UtenteApp getUtenteAppSample1() {
        return new UtenteApp()
            .id(1L)
            .username("username1")
            .email("email1")
            .telefono("telefono1")
            .nome("nome1")
            .cognome("cognome1")
            .luogoNascita("luogoNascita1")
            .dataNascita("dataNascita1")
            .residente("residente1")
            .societa("societa1")
            .sede("sede1")
            .codfiscale("codfiscale1")
            .telefonoSoc("telefonoSoc1")
            .emailSoc("emailSoc1");
    }

    public static UtenteApp getUtenteAppSample2() {
        return new UtenteApp()
            .id(2L)
            .username("username2")
            .email("email2")
            .telefono("telefono2")
            .nome("nome2")
            .cognome("cognome2")
            .luogoNascita("luogoNascita2")
            .dataNascita("dataNascita2")
            .residente("residente2")
            .societa("societa2")
            .sede("sede2")
            .codfiscale("codfiscale2")
            .telefonoSoc("telefonoSoc2")
            .emailSoc("emailSoc2");
    }

    public static UtenteApp getUtenteAppRandomSampleGenerator() {
        return new UtenteApp()
            .id(longCount.incrementAndGet())
            .username(UUID.randomUUID().toString())
            .email(UUID.randomUUID().toString())
            .telefono(UUID.randomUUID().toString())
            .nome(UUID.randomUUID().toString())
            .cognome(UUID.randomUUID().toString())
            .luogoNascita(UUID.randomUUID().toString())
            .dataNascita(UUID.randomUUID().toString())
            .residente(UUID.randomUUID().toString())
            .societa(UUID.randomUUID().toString())
            .sede(UUID.randomUUID().toString())
            .codfiscale(UUID.randomUUID().toString())
            .telefonoSoc(UUID.randomUUID().toString())
            .emailSoc(UUID.randomUUID().toString());
    }
}
